pub fn rule_diff(
tree: &ExprTree,
rule: Rule,
log2_sizes: &[f64],
compute_rw: bool,
) -> Option<RuleDiff>Expand description
Compute the complexity difference for applying a rule to a tree.
This computes the local change in complexity without recomputing the entire tree.